==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1MetricStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1MetricStatusFluent<A extends V2beta1MetricStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ExternalMetricStatus getExternal();
    public V2beta1ExternalMetricStatus buildExternal();
    public A withExternal(V2beta1ExternalMetricStatus external);
    public Boolean hasExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> withNewExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> withNewExternalLike(V2beta1ExternalMetricStatus item);
    public V2beta1MetricStatusFluent.ExternalNested<A> editExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> editOrNewExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> editOrNewExternalLike(V2beta1ExternalMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ObjectMetricStatus getObject();
    public V2beta1ObjectMetricStatus buildObject();
    public A withObject(V2beta1ObjectMetricStatus object);
    public Boolean hasObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> withNewObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> withNewObjectLike(V2beta1ObjectMetricStatus item);
    public V2beta1MetricStatusFluent.ObjectNested<A> editObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> editOrNewObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> editOrNewObjectLike(V2beta1ObjectMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1PodsMetricStatus getPods();
    public V2beta1PodsMetricStatus buildPods();
    public A withPods(V2beta1PodsMetricStatus pods);
    public Boolean hasPods();
    public V2beta1MetricStatusFluent.PodsNested<A> withNewPods();
    public V2beta1MetricStatusFluent.PodsNested<A> withNewPodsLike(V2beta1PodsMetricStatus item);
    public V2beta1MetricStatusFluent.PodsNested<A> editPods();
    public V2beta1MetricStatusFluent.PodsNested<A> editOrNewPods();
    public V2beta1MetricStatusFluent.PodsNested<A> editOrNewPodsLike(V2beta1PodsMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ResourceMetricStatus getResource();
    public V2beta1ResourceMetricStatus buildResource();
    public A withResource(V2beta1ResourceMetricStatus resource);
    public Boolean hasResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> withNewResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> withNewResourceLike(V2beta1ResourceMetricStatus item);
    public V2beta1MetricStatusFluent.ResourceNested<A> editResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> editOrNewResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> editOrNewResourceLike(V2beta1ResourceMetricStatus item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface ExternalNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ExternalMetricStatusFluent<V2beta1MetricStatusFluent.ExternalNested<N>>{

        
    public N and();    public N endExternal();
}
    public interface ObjectNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ObjectMetricStatusFluent<V2beta1MetricStatusFluent.ObjectNested<N>>{

        
    public N and();    public N endObject();
}
    public interface PodsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1PodsMetricStatusFluent<V2beta1MetricStatusFluent.PodsNested<N>>{

        
    public N and();    public N endPods();
}
    public interface ResourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ResourceMetricStatusFluent<V2beta1MetricStatusFluent.ResourceNested<N>>{

        
    public N and();    public N endResource();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1MetricStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;

public interface V2beta1MetricStatusFluent<A extends V2beta1MetricStatusFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ExternalMetricStatus getExternal();
    public V2beta1ExternalMetricStatus buildExternal();
    public A withExternal(V2beta1ExternalMetricStatus external);
    public Boolean hasExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> withNewExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> withNewExternalLike(V2beta1ExternalMetricStatus item);
    public V2beta1MetricStatusFluent.ExternalNested<A> editExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> editOrNewExternal();
    public V2beta1MetricStatusFluent.ExternalNested<A> editOrNewExternalLike(V2beta1ExternalMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ObjectMetricStatus getObject();
    public V2beta1ObjectMetricStatus buildObject();
    public A withObject(V2beta1ObjectMetricStatus object);
    public Boolean hasObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> withNewObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> withNewObjectLike(V2beta1ObjectMetricStatus item);
    public V2beta1MetricStatusFluent.ObjectNested<A> editObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> editOrNewObject();
    public V2beta1MetricStatusFluent.ObjectNested<A> editOrNewObjectLike(V2beta1ObjectMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1PodsMetricStatus getPods();
    public V2beta1PodsMetricStatus buildPods();
    public A withPods(V2beta1PodsMetricStatus pods);
    public Boolean hasPods();
    public V2beta1MetricStatusFluent.PodsNested<A> withNewPods();
    public V2beta1MetricStatusFluent.PodsNested<A> withNewPodsLike(V2beta1PodsMetricStatus item);
    public V2beta1MetricStatusFluent.PodsNested<A> editPods();
    public V2beta1MetricStatusFluent.PodsNested<A> editOrNewPods();
    public V2beta1MetricStatusFluent.PodsNested<A> editOrNewPodsLike(V2beta1PodsMetricStatus item);
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ResourceMetricStatus getResource();
    public V2beta1ResourceMetricStatus buildResource();
    public A withResource(V2beta1ResourceMetricStatus resource);
    public Boolean hasResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> withNewResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> withNewResourceLike(V2beta1ResourceMetricStatus item);
    public V2beta1MetricStatusFluent.ResourceNested<A> editResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> editOrNewResource();
    public V2beta1MetricStatusFluent.ResourceNested<A> editOrNewResourceLike(V2beta1ResourceMetricStatus item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface ExternalNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ExternalMetricStatusFluent<V2beta1MetricStatusFluent.ExternalNested<N>>{

        
    public N and();    public N endExternal();
}
    public interface ObjectNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ObjectMetricStatusFluent<V2beta1MetricStatusFluent.ObjectNested<N>>{

        
    public N and();    public N endObject();
}
    public interface PodsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1PodsMetricStatusFluent<V2beta1MetricStatusFluent.PodsNested<N>>{

        
    public N and();    public N endPods();
}
    public interface ResourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ResourceMetricStatusFluent<V2beta1MetricStatusFluent.ResourceNested<N>>{

        
    public N and();    public N endResource();
}


}
